
# Animal-Script

AnimalScript is a playful and educational programming language designed for fun and learning. It features a syntax inspired by animals and provides an engaging environment for experimenting with programming concepts.



## Installation

You can install AnimalScript using pip: <br>

```bash
pip install animal-script
```
    
## Usage/Examples

To use AnimalScript, simply run the animal-script command followed by your AnimalScript code. <br> For example: <br>
```bash
animal-script my_script.animal 
```
Replace my_script.animal with the path to your AnimalScript file. <br>

Manual Execution:  <br>
```bash
python -m animal_script.interpreter my_script.animal
```

## Lessons

**Variable Assignment:**

Syntax: 
```bash 
<Animal> <variable_name> = <value>
```
Example: 
```bash
Dolphin age = 10
```

**Arithmetic Operations:**

Syntax:
```bash 
<Animal> <variable_name> <operator> <value>
```
Example: 
```bash
Elephants total = 20 + 5
```

### Control Statements:

**For Loop:**

Syntax: 
```bash
Monkeys <variable_name> <start> <end> [<step>]
```
Example: 
```bash
Monkeys i 0 5
```

**If Condition:**

Syntax: 
```bash
Tiger <condition>
```
Example: 
```bash
Tiger i < 10
```

**Print Statement:**

Syntax: 
```bash
Whale <message>
```
Example: 
```bash
Whale "Hello, World!"
```

**Input Statement:**

Syntax: 
```bash
Dolphin <variable_name>
```
Example: 
```bash
Dolphin age
```

**Comments:**

Syntax: 
```bash
#<comment>
```

Example: 
```bash
# This is a comment
```

**Concatenation:**

Syntax: 
```bash
<Animal> <variable_name> = <value1> + <value2>
```
Example: 
```bash
Elephants message = "Hello" + "World"
```

**If Statement with Print:**

Syntax:
```bash
Tiger <condition>
Whale <message>
```

Example:
```bash
Tiger age > 18
Whale "You are an adult"
```

**If Statement with Variable:**

Syntax:
```bash
Tiger <condition>
Dolphin <variable_name>
```

Example:
```bash
Tiger age < 18
Dolphin underage
```

**For Loop with Print:**

Syntax:
```bash
Monkeys <variable_name> <start> <end> [<step>]
Whale <message>
```

Example:
```bash
Monkeys i 1 5
Whale "Iteration: i"
```
## License

[MIT](https://choosealicense.com/licenses/mit/)

This project is licensed under the MIT License - see the LICENSE file for details.
## Contributing

Contributions are always welcome!

See `contributing.md` for ways to get started.

If you'd like to contribute to AnimalScript, feel free to submit pull requests or open issues on the GitHub repository: 
https://github.com/adnanattar/animal-script

## Frequently Asked Questions (FAQ)

### What is AnimalScript?
AnimalScript is a domain-specific language (DSL) designed to mimic natural language syntax, making it intuitive and easy to understand. It is primarily used for scripting and automation tasks.

### How do I install AnimalScript?
You can install AnimalScript using pip:

```bash
pip install animal-script
```

### How do I use AnimalScript?
AnimalScript files typically have a `.animal` extension. You can run an AnimalScript file using the `animal-script` command followed by the filename:

```bash
animal-script my_script.animal
```

### What are some common control statements in AnimalScript?
AnimalScript provides intuitive control statements that mimic natural language. Some common ones include:
- `Monkeys`: For loop
- `Tiger`: If condition
- `Dolphin`: Input statement
- `Whale`: Print statement

### Can I contribute to AnimalScript?
Yes, contributions are welcome! Feel free to submit pull requests or open issues on the GitHub repository.

### How do I report a bug or suggest a feature?
You can report bugs or suggest features by opening an issue on the GitHub repository.

### Where can I find more information about AnimalScript?
You can find more information, documentation, and examples on the AnimalScript GitHub repository: [link](https://github.com/adnanattar/animal-script).

### Is there a code of conduct for contributing to AnimalScript?
Yes, please refer to the [CODE_OF_CONDUCT.md](CODE_OF_CONDUCT.md) file for guidelines on contributing to AnimalScript.

### How can I get help or support?
If you need help or have questions about AnimalScript, you can reach out to the community on the GitHub repository or the official support channels.

### Can I use AnimalScript for commercial projects?
Yes, AnimalScript is open-source and available under the [MIT License](LICENSE). You are free to use it for commercial projects.

### How do I uninstall AnimalScript?
You can uninstall AnimalScript using pip:

```bash
pip uninstall animal-script
```

If you have any further questions or need assistance, don't hesitate to ask!
## Authors

- [@adnanattar](https://www.github.com/adnanattar)


## Features

- **Natural Language Syntax**: AnimalScript uses a natural language syntax that mimics everyday speech, making it easy to read and write.
- **Control Statements**: Intuitive control statements such as `Monkeys` for loops, `Tiger` for conditional statements, `Dolphin` for user input, and `Whale` for output.
- **Arithmetic Operations**: Supports basic arithmetic operations such as addition, subtraction, multiplication, and division.
- **Variable Management**: Easily manage variables and store values for later use.
- **Error Handling**: Provides informative error messages for invalid input or operations.
- **File Input**: Run AnimalScript files directly from the command line.
- **Extensible**: Easily extendable with custom functions and modules.
- **Open Source**: AnimalScript is open-source and available under the MIT License.
- **Cross-Platform**: Runs on any platform that supports Python.

These are just a few of the features that make AnimalScript a powerful and versatile scripting language.


## Support

For any questions or support, please contact support@androtechbuddy.com.

